clear all
clc
format long

%---------------------------PROGRAM: FOCASTREAM 1.0------------------------
%FOrce CAlculation on a cylinder subjected to a STREAM function wave
%
%Written by Espen Engebretsen during completion of Master Thesis 02.06.2012
%
%Email: e.engebretsen@me.com
%
%
%This version is compatible with Fourier.exe by John D. Fenton version
%update May 24, 2012. Freely available at 
%http://johndfenton.com/Steady-waves/Fourier.html
%
%Please download and install Fourier.exe into the same folder as this 
%program. FOCASTREAM consists of the files FOCASTREAM.m, write_input.m and 
%get_output.m which all must be present in the same folder.
%
%Please consult the Introduction.pdf when chosing input for this program.
%
%Fourier.exe is completely controlled from this program, one does not
%need to manually change the input file for Fourer.exe
%
%
%To view the dimensionless wave profile and kinematics, download GNUplot,
%freely available http://www.gnuplot.info/download.html and open Figure.plt
%generated by Fourier.exe
%
%
%-------------------------------------------------------------------------%
%                                   INPUT
%-------------------------------------------------------------------------%
n_FS=100;               %Number of points on free surface (clustered near crest) [integer]
n_PH=181;               %Number of phases over half a wavelength [integer]
n_VP=300;               %Number of vertical points in each profile, i.e  
                        %number of locations to calculate kinematics [integer]

%PLEASE REMARK THAT WHAT IS MEANT BY PHASE IN FENTONS PROGRAM IS REALLY
%360-omega*t. So that a phase equal to 15degrees is really when
%omega*t=345degrees. The wave is simulated for omega*t=180 to omega*t=360.

d=20.69;                %Water Depth [m]     
T=16.28;                %Wave Period [s]
g=9.81;                 %Acceleration of gravity [m/s^2]
H=12.5;                 %Wave Height [m]
rho=1025;               %Density of water [kg/m^3]
c_m=2;                  %Mass coefficient [-]
c_d=0.80855;            %Drag coefficient [-]
cyl_D=6;                %Cylider Diameter [-]
cyl_length=50;          %Length of cylinder [m]
current_crit=1;         %Current criterion
current_mag=0;          %Current magnitude
st_order=14;            %Stream Function Order [integer]
h_steps=2;             %Number of Height steps [integer]
iter_max=100;           %Maximum number of iterations [integer]
conv_crit=1*10^(-5);    %Convergence criterion

snap_phase=10;           %At what phase [deg] (from 0 to 180) to
                        %display a snapshot of strips at cylinder (THIS IS
                        %FENTON-degrees(i.e 360-omega*t)
%-------------------------------------------------------------------------%
%                               END OF INPUT
%-------------------------------------------------------------------------%

message = sprintf('A command window running Fenton.exe for calculating kinematics will now appear.\n\nPlease press a button (as the command window requests), and then close the command window.\n\nPost processing will then continue.\n\n PRESS OK (ONCE) TO CONTINUE, AND THEN WAIT');
uiwait(msgbox(message,'INFORMATION','help'));



%MAKING INPUT FILES AND RUNNING FOURIER.EXE

write_input( n_FS,n_PH,n_VP,H,d,T,g,st_order,h_steps,iter_max,conv_crit,current_crit,current_mag );

!Fourier.exe &

%%
[ lambda,c_w,order,y,u,dudt,v,dudy,dudx,DuDt,x,eta ] = get_output(d,g,n_VP,n_PH  );


                            %CALCULATIONG BASE SHEAR AND OVERUTNING MOMENT
                            %ACCORDING TO TRADITIONAL MORISON
for j=1:n_PH
    temp_force_mass=rho*pi*c_m*(0.25*cyl_D^2)*trapz(y(:,j),DuDt(:,j));
    temp_force_drag=0.5*rho*c_d*cyl_D*trapz(y(:,j),(abs(u(:,j)).*u(:,j)));
    
    force_tot(j)=temp_force_mass+temp_force_drag;
    
    temp_moment_mass=rho*pi*c_m*(0.25*cyl_D^2)*trapz(y(:,j),DuDt(:,j).*y(:,j));
    temp_moment_drag=0.5*rho*cyl_D*c_d*trapz(y(:,j),(abs(u(:,j)).*u(:,j)).*y(:,j));
    
    moment_tot(j)=temp_moment_mass+temp_moment_drag;        
    
end


[Max_Base_Shear pos_MBS]=max(force_tot); %Max base shear and position

MBS_phase=(pos_MBS-1)*(181/n_PH);                     %Phase [deg] of max base shear

[Max_O_Moment pos_MOM]=max(moment_tot);  %Max overturning moment and position
        
MOM_phase=(pos_MOM-1)*(181/n_PH);                    %Phase [deg] of max overturning moment




%%



u_surf=u(n_VP,:);                      %Horizontal velocity along surface
phases=[0:180/(n_PH-1):180];        %Phases considered

for j=1:n_PH                         %Done for the following phases
    
   
%Point of full submergence
temp_phase=(j-1)*(181/n_PH);                             %Phase considered
x_val_r=(cyl_D/2)+(lambda/360)*temp_phase;  %Last point of full submergence (LPFS) (right)
x_val_l=(-cyl_D/2)+(lambda/360)*temp_phase; %Last point of submergence (left) NOT USED
[delta pos]=min(abs(x-x_val_r));
    
    %Linear interpolation to find wave elevation at right cylinder edge
    if x(pos)>=x_val_r          %If LPFS is less than the closest x value
        x1=x(pos);
        x2=x(pos-1);
        eta1=eta(pos);
        eta2=eta(pos-1);
        eta_cyl_r(j)=((eta2-eta1)/(x2-x1))*(x_val_r-x2)+eta2;       %wave elevation at cylinder edge
        
%         figure(99)
%         plot([x1 x2],[eta1 eta2])
%         hold on
%         plot(x_val,eta_cyl(count),'k.')
         %plot(x-(lambda/360)*temp_phase,eta,'r')
        
    elseif x(pos)<=x_val_r && pos<length(x)  %If LPFS is larger than the closest x value
        x1=x(pos);
        x2=x(pos+1);
        eta1=eta(pos);
        eta2=eta(pos+1);
        eta_cyl_r(j)=((eta2-eta1)/(x2-x1))*(x_val_r-x2)+eta2;   %Linearly interpolated surface elevation at cylinder edge(right)
        
%         figure(99)
%         plot([x2 x1],[eta2 eta1])
%         hold on
%         plot(x_val,eta_cyl(count),'k.')
         %plot(x-(lambda/360)*temp_phase,eta,'r')
         
         
    elseif x(pos)<x_val_r && pos==length(x)
             eta_cyl_r(j)=eta(pos);
              %plot(x_val,eta_cyl(count),'k.')
 
    end
    
    
   
temp_x=-x-(lambda/360)*temp_phase;
    
    
    
    
    
%MORISON FOR FULLY SUBMERGED STRIPS
    
    
[diff_y y2]=min(abs(y(:,j)-eta_cyl_r(j))); %y2 is the vertical point closest to LPFS at phase considered

%ALTERED
%temp_force_mass=rho*pi*c_m*(0.25*cyl_D^2)*trapz(y(1:y2,j),DuDt(1:y2,j));         %mass force up to LPFS at phase considered
%temp_force_drag=0.5*rho*c_d*cyl_D*trapz(y(1:y2,j),(abs(u(1:y2,j)).*u(1:y2,j))); %drag force up to LPFS at phase considered

temp_force_mass=rho*pi*c_m*(0.25*cyl_D^2)*trapz(y(:,j),DuDt(:,j));         %mass force up to LPFS at phase considered
temp_force_drag=0.5*rho*c_d*cyl_D*trapz(y(:,j),(abs(u(:,j)).*u(:,j))); %drag force up to LPFS at phase considered



%ALTERED
%temp_moment_mass=rho*pi*c_m*(0.25*cyl_D^2)*trapz(y(1:y2,j),DuDt(1:y2,j).*y(1:y2,j));        %mass moment up to LPFS at phase considered
%temp_moment_drag=0.5*rho*cyl_D*c_d*trapz(y(1:y2,j),(abs(u(1:y2,j)).*u(1:y2,j)).*y(1:y2,j)); %drag moment up to LPFS at phase considered

temp_moment_mass=rho*pi*c_m*(0.25*cyl_D^2)*trapz(y(:,j),DuDt(:,j).*y(:,j));        %mass moment up to LPFS at phase considered
temp_moment_drag=0.5*rho*cyl_D*c_d*trapz(y(:,j),(abs(u(:,j)).*u(:,j)).*y(:,j)); %drag moment up to LPFS at phase considered



%SLAMMING CONTRIBUTION
count=0;

%ALTERED
%[diff_y y3]=min(abs(y(:,1)-eta_cyl_r(j)));  %y3=position of y-coord closest wave elevation at cylinder edge, for PHASE=0;
[diff_y y3]=min(abs(y(:,1)-y(n_VP,j)));


Cs=[];                  %Cs at strips
u_strip=[];             %Velocity at strips
temp_y=[];              %Strip locations
submerge=0;

[s ss]=size(y);         %s is the number of y values, ss is the number of phases
        
if y3<(n_VP)    %If the position of wave elevation at cylinder edge is below the wave crest
    
    
  
    for ii=(y3+1):n_VP   %This is done for the vertical point ABOVE wave elevation 
                         %at cylinder edge and up to the vertical position of the wave crest
                         %(At the vertical position of the wave elev at
                         %cylinder edge, the values will manually be
                         %inserted at the end)
        
        if ii<n_VP       %If the vertical position considered is below the wave crest
        [k l]=min(abs(eta-y(ii,1)));    %Find location of the wave elevation value
                                        %that is closest to the y-value
                                        %considered
        
        else                            %If the vertical position considered is at the wave crest
        [k l]=min(abs(eta-y(ii,1)));    %IS THIS NEEDED?
        end



        
        %------------------------------------------------------------------
        %Linearly interpolated x position of surface elevation at given y - called
        %eta_x
        if y(ii,1)>=eta(l)
        x1=temp_x(l+1);
        eta1=eta(l+1);
        
        elseif y(ii,1)<eta(l)
        x1=temp_x(l-1);
        eta1=eta(l-1);
        end
        
        x2=temp_x(l);
        eta2=eta(l);
        
        if eta1~=eta2
        eta_x=((x2-x1)/(eta2-eta1))*(y(ii,1)-eta2)+x2;     
        
        else
            eta_x=-(lambda/360)*temp_phase;        
        end
        %------------------------------------------------------------------
        
        %------------------------------------------------------------------      
        if ((cyl_D/2)+eta_x)>=0         %If the x position of surface elevation at given y 
                                        %is to the right of the cylinders
                                        %left boundary
            count=count+1;
            submerge=(cyl_D/2)+eta_x;   %How much the strip is suberged
            Cs(count,1)=5.15*((cyl_D/(cyl_D+19*submerge))+(0.107*submerge/cyl_D));
            length_s(count,1)=submerge;
       
                           
        u_phase=eta_x*360/lambda+temp_phase;    %At what phase to find horizontal
                                                %velocity of surface at
                                                %given y
                       
        [m n]=min(abs(phases-u_phase));
        
                %----------------------------------------------------------
                %Linearly interpolated surface speed at given y (each strip)
                if u_phase>=phases(n)
                    ph1=phases(n+1);
                    u1=u_surf(n+1);

                elseif u_phase<phases(n) && n>1
                    ph1=phases(n-1);
                    u1=u_surf(n-1);
                    
                elseif u_phase<phases(n) && n==1
                    ph1=phases(n);
                    u1=u_surf(n);
                    
                    
                end
                


                ph2=phases(n);
                u2=u_surf(n);
                
                if u1~=u2
                u_s=((u2-u1)/(ph2-ph1))*(u_phase-ph2)+u2;  
                else
                u_s=u1;
                
                end
               
                %if count~=0 
                u_strip(count,1)=u_s;
                %end
                %----------------------------------------------------------
        end
        
        %------------------------------------------------------------------
        
        
        %------------------------------------------------------------------      
        %For lowest strip:
        
        u_phase2=(cyl_D/2)*360/lambda+temp_phase;   %At what phase to find horizontal 
                                                    %velocity at LPFS
       
        if u_phase2<=180;
        
        [m n]=min(abs(phases-u_phase2));        
         
        if u_phase2>=phases(n)

        
            ph12=phases(n+1);
            u12=u_surf(n+1); 
            
        elseif u_phase2<phases(n)
            ph12=phases(n-1);
            u12=u_surf(n-1);
        end
        
        
        ph22=phases(n);
        u22=u_surf(n);
        u_s2=((u22-u12)/(ph22-ph12))*(u_phase2-ph22)+u22;  
        end
        
        %------------------------------------------------------------------
       

    if j==snap_phase*(n_PH/181)+1
        
    figure(8)
    xlim([-cyl_D*2.5 cyl_D*2.5])
    ylim([d-H/3 d+H])
    hold on
    plot(x-(lambda/360)*temp_phase,eta)
    plot([cyl_D/2 cyl_D/2],[0 cyl_length],'m','displayname','Cylinder')
    plot([-cyl_D/2 -cyl_D/2],[0 cyl_length],'m')
    plot([-cyl_D/2 cyl_D/2],[cyl_length cyl_length],'m')
    
    if eta_x>(-cyl_D/2)
    plot([-cyl_D/2 -cyl_D/2+submerge],[y(ii,1) y(ii,1)],'k') 
    %plot(eta_x,y(ii,1),'.k')
    end
    
%ALTERED    
    %plot([-cyl_D/2 cyl_D/2],[eta_cyl_r(j) eta_cyl_r(j)],'k')
    plot([-cyl_D/2 0],[y(n_VP,j) y(n_VP,j)],'k')
    if ii==n_VP
     
    xlabel('x [m]')
    ylabel('y [m]')
    str=['Snapshot at {\omega}t=',num2str(360-snap_phase),' deg'];
    title(str)
    
    pbaspect([2*cyl_D*2.5 (H/3)+H 1])
    end
    
%ALTERED    
    %plot(cyl_D/2,eta_cyl_r(j),'.g')
    plot(0,y(n_VP,j),'.g')
    
    hold off
    end
        

    
     
    end
    
    
    
     
    if length(y(y3+1:y3+length(Cs)-1,1))==length(Cs)   %MULIG FEIL?
    
    temp_y=[eta_cyl_r(j);y(y3+1:y3+length(Cs)-1,1)];    %y-values of slamming-strips
    else
        
    temp_y=[eta_cyl_r(j);y(y3+1:y3+1+length(Cs)-1,1)];
    end
    
%ALTERED    
    %u_strip=[u_s2;u_strip];       %velocity at slamming strips
    %Cs=[0.80855;Cs];
    
    u_strip=[u(n_VP,j);u_strip];       
    Cs=[5.15*((cyl_D/(cyl_D+19*cyl_D/2))+(0.107*(cyl_D/2)/cyl_D));Cs];
    
     
    if length(Cs)>1
    temp_force_slam=0.5*rho*cyl_D*trapz(temp_y,Cs.*u_strip.*u_strip);
    slam_force(j)=temp_force_slam;
    
    force_tot_SLAMMING(j)=temp_force_mass+temp_force_drag+temp_force_slam;
    no_slam_force(j)=temp_force_mass+temp_force_drag;
    
    temp_moment_slam=0.5*rho*cyl_D*trapz(temp_y,Cs.*u_strip.*u_strip.*temp_y);
    slam_moment(j)=temp_moment_slam;
    moment_tot_SLAMMING(j)=temp_moment_mass+temp_moment_drag+temp_moment_slam;  
    
    
 
    
    
    %PLOT FORCE FOR STRIPS
    
    
    
    
    
    
    else %ONE OR ZERO STRIPS
    
    slam_force(j)=0;    
    no_slam_force(j)=temp_force_mass+temp_force_drag;   
    force_tot_SLAMMING(j)=temp_force_mass+temp_force_drag;
    
    moment_tot_SLAMMING(j)=temp_moment_mass+temp_moment_drag;
    slam_moment(j)=0;
     
  
    
    
     end
    
    
else
    slam_force(j)=0;    
    no_slam_force(j)=temp_force_mass+temp_force_drag;
    force_tot_SLAMMING(j)=temp_force_mass+temp_force_drag;
    moment_tot_SLAMMING(j)=temp_moment_mass+temp_moment_drag;
    slam_moment(j)=0;
    
    if j==snap_phase*(n_PH/181)+1
        
    figure(8)
    xlim([-cyl_D*2.5 cyl_D*2.5])
    ylim([d-H/3 d+H])
    hold on
    plot(x-(lambda/360)*temp_phase,eta)
    plot([cyl_D/2 cyl_D/2],[0 cyl_length],'m','displayname','Cylinder')
    plot([-cyl_D/2 -cyl_D/2],[0 cyl_length],'m')
    plot([-cyl_D/2 cyl_D/2],[cyl_length cyl_length],'m')
    
    %ALTERED
    plot([-cyl_D/2 0],[y(n_VP,j) y(n_VP,j)],'k')
    
     
    xlabel('x [m]')
    ylabel('y [m]')
    str=['Snapshot at {\omega}t=',num2str(360-snap_phase),' deg. WARNING: No vertical points above morison limit'];
    title(str)
    
    pbaspect([2*cyl_D*2.5 (H/3)+H 1])
    
    %ALTERED
    plot(0,y(n_VP,j),'.g')
    
    
    hold off
    end
    
    
end


    
    
    

    
    
    
    
    
end
%%


[Max_Base_Shear_slam pos_MBS_slam ]=max(force_tot_SLAMMING);

MBS_phase_slam=(pos_MBS_slam-1)*(181/n_PH); 

[Max_O_Moment_slam pos_MOM_slam ]=max(moment_tot_SLAMMING);

MOM_phase_slam =(pos_MOM_slam-1)*(181/n_PH); 





%%
str1=['| Max Base Shear:         ',num2str(Max_Base_Shear/10^6),'  [MN].  Appears at omega*t: ',num2str(360-MBS_phase),' [deg]      |'];
str2=['| Max overturning Moment: ',num2str(Max_O_Moment/10^6),  ' [MNm]. Appears at omega*t: ',num2str(360-MOM_phase),' [deg]      |'];
str3=['| Wave Height:            ',num2str(H),'    [m]                                    |'];
str33=['| Crest Height:           ',num2str(y(n_VP,1)-d),'    [m]                                    |'];
str4=['| Wave Period:            ',num2str(T),'   [s]                                    |'];
str5=['| Water Depth:            ',num2str(d),'   [m]                                    |'];
str6=['| Wave Length:            ',num2str(lambda),'[m]                                    |'];
str7=['| Wave speed:             ',num2str(c_w),'  [m/s]                                  |'];
str8=['| Stream Function Order   ',num2str(st_order),'th                                            |'];
str9=['| Max Base Shear:         ',num2str(Max_Base_Shear_slam/10^6),'  [MN].  Appears at omega*t: ',num2str(360-MBS_phase_slam),' [deg]      |'];
str10=['| Max overturning Moment: ',num2str(Max_O_Moment_slam/10^6),  ' [MNm]. Appears at omega*t: ',num2str(360-MOM_phase_slam),' [deg]      |'];
str11=['| Max Base Shear:         ',num2str((Max_Base_Shear_slam/Max_Base_Shear)*100-100),'  %'];
str12=['| Max overturning Moment: ',num2str((Max_O_Moment_slam/Max_O_Moment)*100-100),  ' %'];


disp('|------------------------------------------------------------------------|')
disp('|                                 INPUT                                  |')
disp('|------------------------------------------------------------------------|')
disp('|                                                                        |')
disp(str3)
disp(str4)
disp(str5)
disp('|                                                                        |')
disp(str8)
disp('|                                                                        |')
disp('|------------------------------------------------------------------------|')
disp('|                                 RESULTS                                |')
disp('|------------------------------------------------------------------------|')
disp('|                                                                        |')
disp(str6)
disp(str7)
disp(str33)
disp('|                                                                        |')
disp('| Max Base Shear and Overturning Moment from traditional morison:        |')
disp(str1) 
disp(str2)
disp('|                                                                        |')
disp('| Max Base Shear and Overturning Moment when including slamming:        |')
disp(str9)
disp(str10)
disp('|                                                                        |')
disp('| Percentage increase du to slamming:')
disp(str11)
disp(str12)
disp('|------------------------------------------------------------------------|')

    %%
    % WAJAC
% u_wajac=[6.66100000000000;6.57500000000000;6.49000000000000;6.40700000000000;6.32600000000000;6.24700000000000;6.16900000000000;6.09300000000000;6.01900000000000;5.94700000000000;5.87600000000000;5.80700000000000;5.73900000000000;5.67300000000000;5.60800000000000;5.54500000000000;5.48400000000000;5.42300000000000;5.36400000000000;5.30700000000000;5.25000000000000;5.19500000000000;5.14200000000000;5.08900000000000;5.03800000000000;4.98800000000000;4.93900000000000;4.89100000000000;4.84400000000000;4.79900000000000;4.75500000000000;4.71100000000000;4.66900000000000;4.62800000000000;4.58800000000000;4.54800000000000;4.51000000000000;4.47300000000000;4.43600000000000;4.40100000000000;4.36700000000000;4.33300000000000;4.30000000000000;4.26900000000000;4.23800000000000;4.20800000000000;4.17800000000000;4.15000000000000;4.12200000000000;4.09600000000000;4.07000000000000;4.04400000000000;4.02000000000000;3.99600000000000;3.97300000000000;3.95100000000000;3.93000000000000;3.90900000000000;3.88900000000000;3.87000000000000;3.85100000000000;3.83300000000000;3.81600000000000;3.79900000000000;3.78400000000000;3.76800000000000;3.75400000000000;3.74000000000000;3.72700000000000;3.71400000000000;3.70200000000000;3.69100000000000;3.68100000000000;3.67000000000000;3.66100000000000;3.65200000000000;3.64400000000000;3.63700000000000;3.63000000000000;3.62300000000000;3.61800000000000;3.61300000000000;3.60800000000000;3.60400000000000;3.60100000000000;3.59800000000000;3.59600000000000;3.59500000000000;3.59400000000000;];
% d_wajac=[28.4800000000000;28.1600000000000;27.8400000000000;27.5200000000000;27.2000000000000;26.8800000000000;26.5600000000000;26.2400000000000;25.9200000000000;25.6000000000000;25.2800000000000;24.9600000000000;24.6400000000000;24.3200000000000;24;23.6800000000000;23.3600000000000;23.0400000000000;22.7200000000000;22.4000000000000;22.0800000000000;21.7600000000000;21.4400000000000;21.1200000000000;20.8000000000000;20.4800000000000;20.1600000000000;19.8400000000000;19.5200000000000;19.2000000000000;18.8800000000000;18.5600000000000;18.2400000000000;17.9200000000000;17.6000000000000;17.2800000000000;16.9600000000000;16.6400000000000;16.3200000000000;16;15.6800000000000;15.3600000000000;15.0400000000000;14.7200000000000;14.4000000000000;14.0800000000000;13.7600000000000;13.4400000000000;13.1200000000000;12.8000000000000;12.4800000000000;12.1600000000000;11.8400000000000;11.5200000000000;11.2000000000000;10.8800000000000;10.5600000000000;10.2400000000000;9.92000000000000;9.60000000000000;9.28000000000000;8.96000000000000;8.64000000000000;8.32000000000000;8;7.68000000000000;7.36000000000000;7.04000000000000;6.72000000000000;6.40000000000000;6.08000000000000;5.76000000000000;5.44000000000000;5.12000000000000;4.80000000000000;4.48000000000000;4.16000000000000;3.84000000000000;3.52000000000000;3.20000000000000;2.88000000000000;2.56000000000000;2.24000000000000;1.92000000000000;1.60000000000000;1.28000000000000;0.960000000000000;0.640000000000000;0.320000000000000;];
% a_wajac=[2.94200000000000;2.86600000000000;2.79200000000000;2.72100000000000;2.65100000000000;2.58400000000000;2.51900000000000;2.45600000000000;2.39500000000000;2.33500000000000;2.27800000000000;2.22200000000000;2.16800000000000;2.11500000000000;2.06400000000000;2.01500000000000;1.96700000000000;1.92000000000000;1.87500000000000;1.83200000000000;1.78900000000000;1.74800000000000;1.70800000000000;1.67000000000000;1.63200000000000;1.59600000000000;1.56000000000000;1.52600000000000;1.49300000000000;1.46100000000000;1.43000000000000;1.40000000000000;1.37100000000000;1.34200000000000;1.31500000000000;1.28800000000000;1.26200000000000;1.23700000000000;1.21300000000000;1.19000000000000;1.16700000000000;1.14500000000000;1.12400000000000;1.10300000000000;1.08300000000000;1.06400000000000;1.04500000000000;1.02700000000000;1.01000000000000;0.993200000000000;0.976900000000000;0.961300000000000;0.946200000000000;0.931600000000000;0.917600000000000;0.904000000000000;0.891000000000000;0.878500000000000;0.866400000000000;0.854800000000000;0.843700000000000;0.833100000000000;0.822800000000000;0.813100000000000;0.803700000000000;0.794800000000000;0.786300000000000;0.778200000000000;0.770500000000000;0.763200000000000;0.756300000000000;0.749800000000000;0.743600000000000;0.737900000000000;0.732500000000000;0.727500000000000;0.722800000000000;0.718500000000000;0.714600000000000;0.711000000000000;0.707700000000000;0.704800000000000;0.702300000000000;0.700100000000000;0.698200000000000;0.696700000000000;0.695500000000000;0.694700000000000;0.694200000000000;];
% d_wajac2=[28.4800000000000;28.1600000000000;27.8400000000000;27.5200000000000;27.2000000000000;26.8800000000000;26.5600000000000;26.2400000000000;25.9200000000000;25.6000000000000;25.2800000000000;24.9600000000000;24.6400000000000;24.3200000000000;24;23.6800000000000;23.3600000000000;23.0400000000000;22.7200000000000;22.4000000000000;22.0800000000000;21.7600000000000;21.4400000000000;21.1200000000000;20.8000000000000;20.4800000000000;20.1600000000000;19.8400000000000;19.5200000000000;19.2000000000000;18.8800000000000;18.5600000000000;18.2400000000000;17.9200000000000;17.6000000000000;17.2800000000000;16.9600000000000;16.6400000000000;16.3200000000000;16;15.6800000000000;15.3600000000000;15.0400000000000;14.7200000000000;14.4000000000000;14.0800000000000;13.7600000000000;13.4400000000000;13.1200000000000;12.8000000000000;12.4800000000000;12.1600000000000;11.8400000000000;11.5200000000000;11.2000000000000;10.8800000000000;10.5600000000000;10.2400000000000;9.92000000000000;9.60000000000000;9.28000000000000;8.96000000000000;8.64000000000000;8.32000000000000;8;7.68000000000000;7.36000000000000;7.04000000000000;6.72000000000000;6.40000000000000;6.08000000000000;5.76000000000000;5.44000000000000;5.12000000000000;4.80000000000000;4.48000000000000;4.16000000000000;3.84000000000000;3.52000000000000;3.20000000000000;2.88000000000000;2.56000000000000;2.24000000000000;1.92000000000000;1.60000000000000;1.28000000000000;0.960000000000000;0.640000000000000;0.320000000000000;];
% x_ax_wajac=[19;18.6000000000000;18.2000000000000;17.8000000000000;17.4000000000000;17;16.6000000000000;16.2000000000000;15.8000000000000;15.4000000000000;15;14.6000000000000;14.2000000000000;13.8000000000000;13.4000000000000;13;12.6000000000000;12.2000000000000;11.8000000000000;11.4000000000000;11;10.6000000000000;10.2000000000000;9.80000000000000;9.40000000000000;9;8.60000000000000;8.20000000000000;7.80000000000000;7.40000000000000;7;6.60000000000000;6.20000000000000;5.80000000000000;5.40000000000000;5;4.60000000000000;4.20000000000000;3.80000000000000;3.40000000000000;3;2.60000000000000;2.20000000000000;1.80000000000000;1.40000000000000;1;0.600000000000000;0.200000000000000;-0.200000000000000;-0.600000000000000;-1;-1.40000000000000;-1.80000000000000;-2.20000000000000;-2.60000000000000;-3;-3.40000000000000;-3.80000000000000;-4.20000000000000;-4.60000000000000;-5;-5.40000000000000;-5.80000000000000;-6.20000000000000;-6.60000000000000;-7;-7.40000000000000;-7.80000000000000;-8.20000000000000;-8.60000000000000;-9;-9.40000000000000;-9.80000000000000;-10.2000000000000;-10.6000000000000;-11;-11.4000000000000;-11.8000000000000;-12.2000000000000;-12.6000000000000;-13;-13.4000000000000;-13.8000000000000;-14.2000000000000;-14.6000000000000;-15;-15.4000000000000;-15.8000000000000;-16.2000000000000;-16.6000000000000;-17;-17.4000000000000;-17.8000000000000;-18.2000000000000;-18.6000000000000;];
% elev_wajac=[22.6000000000000;22.6900000000000;22.7900000000000;22.8800000000000;22.9700000000000;23.0700000000000;23.1700000000000;23.2700000000000;23.3700000000000;23.4700000000000;23.5800000000000;23.6800000000000;23.7900000000000;23.9000000000000;24.0100000000000;24.1200000000000;24.2400000000000;24.3500000000000;24.4700000000000;24.5900000000000;24.7100000000000;24.8300000000000;24.9500000000000;25.0800000000000;25.2000000000000;25.3300000000000;25.4600000000000;25.5900000000000;25.7300000000000;25.8600000000000;25.9900000000000;26.1300000000000;26.2700000000000;26.4100000000000;26.5500000000000;26.6900000000000;26.8300000000000;26.9800000000000;27.1200000000000;27.2600000000000;27.4100000000000;27.5500000000000;27.7000000000000;27.8500000000000;27.9900000000000;28.1400000000000;28.2800000000000;28.4300000000000;28.5700000000000;28.7100000000000;28.8500000000000;28.9900000000000;29.1300000000000;29.2600000000000;29.3900000000000;29.5200000000000;29.6400000000000;29.7500000000000;29.8700000000000;29.9700000000000;30.0700000000000;30.1600000000000;30.2500000000000;30.3200000000000;30.3900000000000;30.4500000000000;30.4900000000000;30.5300000000000;30.5600000000000;30.5700000000000;30.5800000000000;30.5700000000000;30.5600000000000;30.5300000000000;30.4900000000000;30.4400000000000;30.3800000000000;30.3200000000000;30.2400000000000;30.1500000000000;30.0600000000000;29.9600000000000;29.8600000000000;29.7400000000000;29.6300000000000;29.5000000000000;29.3800000000000;29.2500000000000;29.1100000000000;28.9800000000000;28.8400000000000;28.7000000000000;28.5600000000000;28.4100000000000;28.2700000000000;];
% 
% force_wajac=[1800000;1571100;1334800;1097400;864030;638510;423090;218910;26304;-154860;-325000;-484630;-634360;-774750;-906380;-1029800;-1145500;-1253900;-1355600;-1450900;-1540200;-1623800;-1702100;-1775400;-1843900;-1907900;-1967600;-2023300;-2075000;-2123000;-2167500;-2208600;-2246500;-2281300;-2313200;-2342200;-2368600;-2392300;-2413600;-2432600;-2449200;-2463700;-2476100;-2486400;-2494800;-2501300;-2506100;-2509100;-2510500;-2510300;-2508500;-2505300;-2500700;-2494800;-2487500;-2479000;-2469400;-2458600;-2446700;-2433700;-2419800;-2404900;-2389100;-2372400;-2354900;-2336600;-2317500;-2297800;-2277300;-2256200;-2234500;-2212200;-2189400;-2166100;-2142400;-2118300;-2093900;-2069300;-2044500;-2019600;-1994600;-1969500;-1944400;-1919500;-1894700;-1869900;-1845400;-1820900;-1796600;-1772400;-1748400;-1724500;-1700800;-1677200;-1653800;-1630600;-1607500;-1584600;-1561900;-1539300;-1516900;-1494700;-1472700;-1450800;-1429100;-1407600;-1386300;-1365100;-1344100;-1323300;-1302700;-1282300;-1262100;-1242000;-1222100;-1202400;-1182900;-1163600;-1144400;-1125500;-1106700;-1088100;-1069600;-1051300;-1033200;-1015300;-997530;-979930;-962480;-945190;-928060;-911080;-894260;-877590;-861060;-844680;-828440;-812340;-796380;-780540;-764840;-749260;-733790;-718440;-703210;-688080;-673060;-658130;-643300;-628560;-613920;-599350;-584870;-570460;-556130;-541870;-527670;-513530;-499450;-485420;-471430;-457490;-443580;-429700;-415840;-402010;-388200;-374390;-360590;-346800;-333000;-319190;-305380;-291550;-277700;-263820;-249920;-235980;-222000;-207980;-193900;-179770;-165590;-151330;-137010;-122600;-108120;-93553;-78894;-64140;-49287;-34329;-19264;-4086;11208;26624;42167;57839;73647;89595;105690;121930;138330;154890;171610;188500;205560;222800;240210;257820;275610;293590;311760;330130;348700;367470;386450;405640;425030;444650;464480;484530;504800;525300;546030;566990;588180;609600;631250;653140;675260;697610;720200;743020;766070;789360;812870;836610;860580;884780;909200;933840;958700;983770;1009100;1034600;1060300;1086200;1112200;1138500;1165000;1191600;1218400;1245400;1272500;1299700;1327100;1354600;1382300;1410000;1437800;1465700;1493600;1521600;1549700;1577800;1605900;1634000;1662100;1690100;1718100;1746000;1773900;1801600;1829200;1856600;1883900;1911000;1937900;1964500;1991000;2017400;2043600;2069700;2095800;2121800;2147800;2173700;2199700;2225700;2251700;2277800;2303900;2330100;2356300;2382500;2408700;2434900;2461200;2487400;2513600;2539700;2565900;2591900;2618000;2643900;2669800;2695600;2721200;2746800;2772200;2797400;2822500;2847300;2872000;2896400;2920500;2944400;2967900;2991200;3014000;3036400;3058400;3079900;3100900;3121300;3141100;3160200;3178500;3196000;3212700;3228300;3242800;3256100;3268100;3278700;3287700;3294900;3300300;3303400;3304200;3302400;3297600;3289400;3277400;3261200;3240200;3213700;3181000;3141000;3092900;3035200;2966500;2885000;2788600;2675100;2542300;2388400;2212500;2015400;];
% figure(55)
% 
% plot([0:1:359],force_wajac)
% hold on
% plot([360:-1:180],force_tot,'r')



% figure(4)
% hold on
% plot(u_wajac,d_wajac,'displayname','u_wajac')
% plot(u(:,14),y(:,14),'r','displayname','fenton')
% hold off
 
% figure(1)
% hold on
% plot(u(:,pos_MBS),y(:,pos_MBS),'displayname','Horizontal Fluid Velocity at Max Base Shear')
% plot(u(:,pos_MOM),y(:,pos_MOM),'r','displayname','Horizontal Fluid Velocity at Max Overturning Moment')
% legend('show')
% xlabel('u [m/s]')
% ylabel('y[m]')
% hold off

% figure(2)
% hold on
% plot(DuDt(:,pos_MBS),y(:,pos_MBS),'displayname','Total Horizontal Fluid Acceleration at Max Base Shear')
% plot(DuDt(:,pos_MOM),y(:,pos_MOM),'r','displayname','Total Horizontal Fluid Acceleration at Max Overturning Moment')
% legend('show')
% xlabel('Du/Dt [m/s]')
% ylabel('y [m]')
% hold off

% figure(3)
% hold on
% plot(x-((lambda/360)*MBS_phase),eta,'displayname','Wave Elevation at Max Base Shear')
% plot(x-((lambda/360)*MOM_phase),eta,'--','displayname','Wave Elevation at Max Overturning Moment')
% plot(x-((lambda/360)*0),eta,'g--','displayname','Wave Elevation at Max Overturning Moment')
% plot([min(x-((lambda/360)*MBS_phase)) max(x-((lambda/360)*MOM_phase))],[d d],'--k','displayname','Mean Water Level')
% plot([cyl_D/2 cyl_D/2],[0 cyl_length],'m','displayname','Cylinder')
% legend('show')

%shadow=area([-cyl_D/2 cyl_D/2],[cyl_length cyl_length],0);
%shadow2=get(shadow,'children');
%set(shadow2,'FaceAlpha',0.5,'FaceColor','m');

% plot([-cyl_D/2 -cyl_D/2],[0 cyl_length],'m')
% plot([-cyl_D/2 cyl_D/2],[cyl_length cyl_length],'m')
% xlabel('x [m]')
% ylabel('y [m]')
% legend('show')
% hold off


    

%%
%ALTERED    
% figure(99)
% hold on
% new_Phase=[360:-1:180];
% plot(new_Phase,force_tot,'displayname','Total force from regular morison')
% plot(new_Phase,force_tot_SLAMMING,'r','displayname','Total force morison+slamming')
% plot(new_Phase,slam_force,'g','displayname','Force contribution from slamming')
% plot(new_Phase,no_slam_force,'c','displayname','Morison integrated up to last totally submerged strip')
% 
% xlabel('{\omega}t [deg] - equivalent to time')
% 
% plot(new_Phase,force_tot+slam_force,'m','displayname','If morison contribution integrated up to wave elevation at midpoint of cylinder')
% legend('show')
% 
% ylabel('Base Shear [N]')


figure(99)
hold on
new_Phase=[360:-1:180];
plot(new_Phase,force_tot,'displayname','Total force from regular morison')
plot(new_Phase,force_tot_SLAMMING,'r','displayname','Total force morison+slamming')
plot(new_Phase,slam_force,'g','displayname','Force contribution from slamming')

xlabel('{\omega}t [deg]')
legend('show')

ylabel('Base Shear [N]')
title('Base Shear as the wave propagates past the cylinder')

figure(100)
hold on
new_Phase=[360:-1:180];
plot(new_Phase,moment_tot,'displayname','Overturning moment from regular morison')
plot(new_Phase,moment_tot_SLAMMING,'r','displayname','Overturning moment morison+slamming')
plot(new_Phase,slam_moment,'g','displayname','Moment contribution from slamming')

xlabel('{\omega}t [deg]')
legend('show')

ylabel('Base Shear [N]')
title('Overturning moment as the wave propagates past the cylinder')


%%

figure(78)
hold on
plot(x,eta,'r')



figure(23)
hold on
plot(x-(lambda/360)*MBS_phase,eta,'displayname','Wave elevation at max base shear')
plot(x-(lambda/360)*MOM_phase,eta,'--','displayname','Wave elevation at max overturning moment')
plot([cyl_D/2 cyl_D/2],[0 cyl_length],'m','displayname','Cylinder')
plot([-150 150],[d d],'--k','displayname','MWL')
legend('show')
xlim([-50 100])
ylim([16 32])

plot([-cyl_D/2 cyl_D/2],[cyl_length cyl_length],'m')
plot([-cyl_D/2 -cyl_D/2],[0 cyl_length],'m')
xlabel('x [m]')
ylabel('y [m]')
title('Wave elevation at max base shear and max overturning moment')

