#
# Plot results using Gnuplot
#

reset

Output = 0 #(0 for Windows graphics, 1 for black and white files for LaTex, 2 for colour, 3 for graphics GIF files)

LW = 3.5
set border lw 1.4
Xscale = 0.8; Yscale = 0.8
set style line 1 linetype 1 linecolor rgb "blue"
set style line 2 linetype 1 linecolor rgb "red"

# Surface profile

set format x "%3.0f"
set format y "%4.1f"
if (Output==0) set xlabel "x/d"; set ylabel "y/d"
if (Output>0) set xlabel "$x/d$" offset 0,-0.5; set ylabel "$\\dfrac{y}{d}$" -1
set title "Surface profile"
set nokey
show xtics
show ytics
set yrange [0:]
set autoscale x
File = 'Surface'
load 'SetOutput.plt'
plot "Surface.res" using 1:2 with lines ls 1;\
     pause -1 "Surface"

# Velocity profiles

set key top center reverse Left horizontal width +4
set format x "%5.2f"
set format y "%4.1f"
if (Output==0) set xlabel "Velocity (dimensionless w.r.t. g & d)";
if (Output>0) set xlabel "Velocity (dimensionless w.r.t. $g$ \\& $d$)" offset 0,-0.5;
set title "Velocity profiles"
File = 'uv'
load 'SetOutput.plt'
plot "Flowfield.res" using 2:1 title "Horizontal" with lines ls 1,\
     "Flowfield.res" using 3:1 title "Vertical" with lines ls 2;\
pause -1 "uv"

# d(Velocity)/dt profiles

set format x "%5.2f"
set format y "%4.1f"
if (Output==0) set xlabel "Partial du/dt and dv/dt (dimensionless w.r.t. g & d)";
if (Output>0) set xlabel "${\\partial u}/{\\partial t}$ and ${\\partial v}/{\\partial t}$  (dimensionless w.r.t. $g$ \\& $d$)" offset 0,-0.5;
set title "Time derivatives of velocity"
File = 'utvt'
load 'SetOutput.plt'
plot "Flowfield.res" using 5:1 title "Horizontal" with lines ls 1,\
     "Flowfield.res" using 6:1 title "Vertical" with lines ls 2;\
     pause -1 "utvt"

