function [fitresult, gof] = createFit(A,B,n_exclude)
%CREATEFIT(A,B)
%  Create a fit.
%
%  Data for 'untitled fit 1' fit:
%      X Input : A
%      Y Output: B
%  Output:
%      fitresult : a fit object representing the fit.
%      gof : structure with goodness-of fit info.
%
%  See also FIT, CFIT, SFIT.

%  Auto-generated by MATLAB on 31-Jan-2012 12:27:23


%% Fit: 'untitled fit 1'.
[xData, yData] = prepareCurveData( A, B );

% Set up fittype and options.
ft = fittype( 'poly1' );
opts = fitoptions( ft );
opts.Lower = [-Inf -Inf];
opts.Upper = [Inf Inf];
opts.Normalize = 'on';
ex = excludedata( xData, yData, 'Indices', [1:1:n_exclude] );
opts.Exclude = ex;

% Fit model to data.
[fitresult, gof] = fit( xData, yData, ft, opts );

% Create a figure for the plots.
figure(3);

% Plot fit with data.
subplot( 2, 1, 1 );
h = plot( fitresult, xData, yData, ex );
legend( h, 'F_{H_{m0}} ', 'Excluded points', 'Linear fit', 'Location', 'SouthEast' );
% Label axes
xlabel('ln(H_{m0})')
ylabel('ln[-ln(1-F_{H_{m0}}(H_{m0}))]')
title('Weibull plot with linear fit')
grid on

% Plot residuals.
subplot( 2, 1, 2 );
h = plot( fitresult, xData, yData, ex, 'residuals' );
legend( h, 'Linear fit - residuals', 'Excluded points', 'Zero Line', 'Location', 'SouthEast' );
% Label axes
xlabel('ln(H_{m0})')
ylabel( 'Residual' );
title('Residuals')
grid on


