clear all
clc

%%
%Reading Environmental Data 
% [Year,mm,dd,hh,~,~,Hs_all,Tp_all,Mdir_all]=textread('Dogger_north.dat',...
% '%f %f %f %f %f %f %f %f %f','headerlines',3);

[Year,mm,dd,hh,~,~,Hs_all,Tp_all,Mdir_all]=textread('Dogger_Nora10_alt1.dat',...
'%f %f %f %f %f %f %f %f %f','headerlines',4);


%%

%INPUT
dir_low=330; dir_high=15;          %Lower and higher limit of direction
%dir_low=180; dir_high=180;          %Omnidirectional
%dir_low=360; dir_high=0;           %Only north
%---------

count=0;
Hs=zeros(0);
Tp=zeros(0);
Mdir=zeros(0);

for i=1:length(Year)
%if Mdir(i)==0 || Mdir(i)==360
    if Mdir_all(i)<=dir_high && Mdir_all(i)>=0 || Mdir_all(i)<=360 && ...
                                                    Mdir_all(i)>=dir_low
%Creating matrices of Hs, Tp and Dir from within the direction interval
%(north)
        count=count+1;
        Hs(count,1)=Hs_all(i);
        Tp(count,1)=Tp_all(i);
        Mdir(count,1)=Mdir_all(i);
    end
end
%%
%CREATING SCATTER DIAGRAM
max_Hs=ceil(max(Hs)*2)/2;   %If Hs interval is 0.5 - (number of columns-1)
%max_Hs=ceil(max(Hs)*4)/4;  %If Hs interval is 0.25

ScatterDiag=zeros(max_Hs*2+1,23); %23: Legger inn enda en kolonne senere (linje 64)

n=length(Mdir);

for j=1:n    
    Hs_dummy=Hs(j);  Tp_dummy=Tp(j);    
    
    [temp_data]=place_HsTp(Hs_dummy,Tp_dummy,max_Hs);  
                                                %Placing the number "1"
                                                %in the correct cell in SD
    ScatterDiag=ScatterDiag+temp_data;
end

for k=1:22
        
        ScatterDiag(((max_Hs*2)+1),k)=sum(ScatterDiag(:,k)); 
                                                    %Sum of Hs|Tp
                                                    %CHANGE "35" if Tp
                                                    %interval changes!
    
end
    
for k=1:max_Hs*2
        
        ScatterDiag(k,24)=sum(ScatterDiag(k,:));    %Sum of Hs|Hs
                                                    %CHANGE "24" if Hs
                                                    %interval changes!                                                   
end

%%
%PLOT SCATTERDIAG
figure(1)
res1=uitable;
set(res1,'Data',ScatterDiag);
set(res1,'ColumnWidth',{45})
 cnames = {'0-1s','1-2s','2-3s','3-4s','4-5s','5-6s','6-7s','7-8s',...
     '8-9s','9-10s','10-11s','11-12s','12-13s','13-14s','14-15s',...
     '15-16s','16-17s','17-18s','18-19s','19-20s','20-21s','21-22s','22-23s'...
     'SUM'};
 rnames = {'0-0.5m','0.5-1m','1-1.5m','1.5-2m','2-2.5m','2.5-3m',...
 '3-3.5m','3.5-4m','4-4.5m','4.5-5m','5-5.5m','5.5-6m','6-6.5m',...
 '6.5-7m','7-7.5m','7.5-8m','8-8.5m','8.5-9m','9-9.5m','9.5-10m',...
'10-10.5m','10.5-11m','11-11.5m','11.5-12m','SUM'};
set(res1,'ColumnName',cnames,'RowName',rnames,'Position',...
    [0 0 1550 720]);



%%
%Cumulative distribution of Hs
P=zeros(0);                                 %Probability matrix
[a b]=size(ScatterDiag);
[s]=find((ScatterDiag(1:a,24))~=0);         %Pos of nonzero values 
                                            %in "Sum of Hs"-column
  
non_zero_SUMS=ScatterDiag(s,24);            %Non zero values of SUM-COLUMN
for i=1:length(s)    
    
    P(i)=sum(non_zero_SUMS(1:i))/(n+1);     %Cumulative distribution values
                                            %exluding zero valued Hs
end



%Calculating average Hs within each Hs interval, and average Tp within each
%Hs interval

[ mean_Hs, mean_lnTpgHs,std_lnTpgHs ] = mean_Hs_Tp( max_Hs,Hs,Tp );
avg_Hs=mean_Hs(s);                          %Excluding zero Hs values

%%
%Creating the log-log cumulative distribution of Hs
format long;

for i=1:length(P)
        
    
    Hsplot(i,1)=log(avg_Hs(i));
    
    Hsplot(i,2)=log(-log(1-P(i)));
    
    
end

%%
%Plotting points and fitted curve

 figure(2)
 plot(Hsplot(:,1),Hsplot(:,2),'.')
%INPUT!
n_exclude=9; %Number of points to exclude !!!, as the Weibull distribution only
            %valid for the upper tail!
            %FEIL! TROR DET ANDRE PLOTTET EKSLUDERER ETT PUNKT FOR MYE ift n_exclude!
fit_F_Hs=fit((Hsplot(n_exclude+1:length(Hsplot),1)),...
    (Hsplot(n_exclude+1:length(Hsplot),2)),'poly1');
hold on
plot(fit_F_Hs);
%hold off
xlabel('ln(H_{m0})')
ylabel('ln[-ln(1-F_{H_{m0}}(H_{m0}))]')
title('Weibull plot with fitted curve')


A=Hsplot(:,1);
B=Hsplot(:,2);
    
createFit(A,B,n_exclude);                  %For vizualization, fit+residuals

beta=fit_F_Hs.p1;              %Beta of Hs-distribution
rho=exp(-fit_F_Hs.p2/beta);    %Rho of Hs-distribution

%%
%Conditional cumulative distribution Ftp|hs
my=mean_lnTpgHs(s);
sigma=std_lnTpgHs(s);

figure(4)
[fit_my, gof] = my_fit(avg_Hs, my);  %Plot my-fit
                                        %There are more options [default]

figure(5)                                        
[fit_sigma, gof2] = sigma_fit(avg_Hs, sigma); %DRLIG FIT? BEDRE MED HAVER OG NYHUS!

%HVORFOR?:
%DNV:Tz - A wave climate description... Tp - med andre fitting funksjoner?

%%
m=50;              %Years

n_years=(Year(length(Year))-Year(1))+...    %Duration of measurements
        (mm(length(mm))-mm(1))/12+(dd(length(dd))-dd(1))/365+...
        (hh(length(hh))-hh(1))/(365*24);

N_m=length(Hs)*m/n_years;    %Estimated number of sea states during m years
                            %within the direction-range!
beta_2=-norminv(1/N_m,0,1);
count=0;

%Circle in Gauss-space
dt=0.01;
for theta=0:dt:2*pi
    count=count+1;
    u_2(count)=beta_2*cos(theta);
    u_1(count)=beta_2*sin(theta);
end


for i=1:length(u_1)
   
  Hs_IFORM(i)=wblinv(normcdf(u_1(i)),rho,beta);
  
  my=fit_my.a_0+fit_my.a_1*Hs_IFORM(i)^fit_my.a_2;
  sigma=fit_sigma.b_0+fit_sigma.b_1*exp(-fit_sigma.b_2*Hs_IFORM(i));
  
  Tp_IFORM(i)=exp(norminv(normcdf(u_2(i)),my,sigma));
    
end

[a b]=max(Hs_IFORM);
Hs_m=a
Tp_m_contour=Tp_IFORM(b)
my=fit_my.a_0+fit_my.a_1*Hs_m^fit_my.a_2;
sigma=fit_sigma.b_0+fit_sigma.b_1*exp(-fit_sigma.b_2*Hs_m);
exp_Tp_g_Hs_m=exp(my+0.5*sigma^2)


%Hs_extrapol=wblinv((1-1/N_m),rho,beta)
Hs_extrapol=exp((log(-log(1/N_m))-fit_F_Hs.p2)/beta)

figure(6)
plot(Tp_IFORM,Hs_IFORM)
% hold on
% plot([0 30],[Hs_extrapol Hs_extrapol],'r')
xlabel('T_p [s]')
ylabel('H_{m0} [m]')
hold on
plot([Tp_m_contour Tp_m_contour],[0 Hs_extrapol],'k--')
plot([0 Tp_m_contour],[Hs_extrapol Hs_extrapol],'k--')
plot([Tp_m_contour],[0],'ks')
plot([0],[Hs_extrapol],'ks')
plot([0 25],[exp(Hsplot(n_exclude+1,1))  exp(Hsplot(n_exclude+1,1))],'r--','LineWidth',1)
%str=num2str(Tp_m_contour);
%text([Tp_m_contour+0.4],[0-0.4],['T_{p,m}'])
%str=num2str(Hs_extrapol);
%text([0-2.2],[Hs_extrapol-0.45],['H_{m0,m}'])

 str=num2str(Tp_m_contour);
 text([Tp_m_contour+0.4],[0-1],['T_{p,50}: ', str(1:5),' s'])
 str=num2str(Hs_extrapol);
 text([0-4],[Hs_extrapol-0.45],['H_{m0,50}: ', str(1:5),' m'])
 
xa = [1 1]*pi; % X-Coordinates in data space 
ya = [exp(Hsplot(n_exclude+1,1)) exp(Hsplot(n_exclude+1,1))+1.5]; % Y-Coordinates in data space 
[xaf,yaf] = ds2nfu(xa,ya); % Convert to normalized figure units 
annotation('arrow',xaf,yaf,'color',[1 0 0]) % Add annotation
text([3.5],[exp(Hsplot(n_exclude+1,1))+0.7],['Validity'],'color',[1 0 0]) 
 hold off


Hs_validity_from=exp(Hsplot(n_exclude+1,1))

